PendingMethodCall

Struct PendingMethodCall 

struct PendingMethodCall {
    serial: NonZeroU32,
    reply_receiver: Receiver<(Sequence, Result<Message>)>,
    pending_method_calls: PendingMethodCalls,
}
A method call whose completion can be awaited or joined with other streams.

This is useful for cache population method calls, where joining the call with an update signal stream can be used to ensure that cache updates are not overwritten by a cache population whose task is scheduled later.

Fields

serial: NonZeroU32reply_receiver: Receiver<(Sequence, Result<Message>)>pending_method_calls: PendingMethodCalls